qustop.Ensemble
===============

.. currentmodule:: qustop

.. autoclass:: Ensemble

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Ensemble.__init__
      ~Ensemble.swap
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Ensemble.density_matrices
      ~Ensemble.dims
      ~Ensemble.is_linearly_independent
      ~Ensemble.is_mutually_orthogonal
      ~Ensemble.probs
      ~Ensemble.shape
      ~Ensemble.states
      ~Ensemble.systems
   
   